@@ -1,9 +1,13 @@
-# Copyright (c) 2020 Watsen Networks.  All Rights Reserved.
+# Copyright (c) 2021 Watsen Networks.  All Rights Reserved.
 
 from __future__ import annotations
 from abc import ABCMeta,abstractmethod
 from aiohttp import web
 class RouteHandler(metaclass=ABCMeta):
+	@abstractmethod
+	async def handle_get_restconf_root(self,request):0
+	@abstractmethod
+	async def handle_get_yang_library_version(self,request):0
 	@abstractmethod
 	async def handle_get_opstate_request(self,request):0
 	@abstractmethod
